pub struct MockOrganizationIntegrationConfigurationApi {
OrganizationIntegrationConfigurationApi_expectations: MockOrganizationIntegrationConfigurationApi_OrganizationIntegrationConfigurationApi,
}Fields
OrganizationIntegrationConfigurationApi_expectations: MockOrganizationIntegrationConfigurationApi_OrganizationIntegrationConfigurationApiImplementations
Sourceimpl MockOrganizationIntegrationConfigurationApi
impl MockOrganizationIntegrationConfigurationApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockOrganizationIntegrationConfigurationApi
impl MockOrganizationIntegrationConfigurationApi
Sourcepub fn expect_create(&mut self) -> &mut Expectation
pub fn expect_create(&mut self) -> &mut Expectation
Create an Expectation for mocking the create method
Sourcepub fn expect_delete(&mut self) -> &mut Expectation
pub fn expect_delete(&mut self) -> &mut Expectation
Create an Expectation for mocking the delete method
Sourcepub fn expect_get(&mut self) -> &mut Expectation
pub fn expect_get(&mut self) -> &mut Expectation
Create an Expectation for mocking the get method
Sourcepub fn expect_update(&mut self) -> &mut Expectation
pub fn expect_update(&mut self) -> &mut Expectation
Create an Expectation for mocking the update method